@@ -1304,102 +1304,6 @@ class JobsOverview(dd.EmptyTable):
 
 from lino.utils.xmlgen.html import E
 
-if False:
-  
-    class NewJobsOverview(Jobs):
-        """
-        """
-        required = dd.required(user_groups=['integ'])
-        label = _("New Contracts Situation") 
-        column_names = "job_desc working candidates probation"
-        
-        parameters = dict(
-          #~ date = models.DateField(default=datetime.date.today,blank=True,null=True),
-          date = models.DateField(blank=True,null=True,verbose_name=_("Date")),
-          contract_type = models.ForeignKey(ContractType,blank=True,null=True),
-          job_type = models.ForeignKey(JobType,blank=True,null=True),
-          )
-        params_panel_hidden = True
-        
-        
-        @dd.displayfield(_("Job"))
-        def job_desc(self,obj,ar):
-            chunks = [ar.obj2html(obj,unicode(obj.function))]
-            chunks.append(pgettext("(place)"," at "))
-            chunks.append(ar.obj2html(obj.provider))
-            chunks.append(' (%d)' % obj.capacity)
-            if obj.remark:
-                chunks.append(' ')
-                chunks.append(E.i(obj.remark))
-            return E.p(*chunks)
-            
-        @dd.displayfield(pgettext("jobs","Working"))
-        def working(self,obj,ar):
-            return obj._working
-            
-        @dd.displayfield(_("Candidates"))
-        def candidates(self,obj,ar):
-            return obj._candidates
-            
-        @dd.displayfield(_("Probation"))
-        def probation(self,obj,ar):
-            return obj._probation
-            
-        @classmethod
-        def get_data_rows(self,ar):
-            """
-            """
-            data_rows = self.get_request_queryset(ar)
-            if ar.param_values.job_type:
-                data_rows = data_rows.filter(type=ar.param_values.job_type)
-            
-            today = ar.param_values.date or datetime.date.today()
-            
-            for job in data_rows:
-                showit = False
-                working = []
-                qs = job.contract_set.order_by('applies_from')
-                if ar.param_values.contract_type:
-                    qs = qs.filter(type=ar.param_values.contract_type)
-                for ct in qs:
-                    if ct.applies_from:
-                        until = ct.date_ended or ct.applies_until
-                        if not until or (ct.applies_from <= today and until >= today):
-                            working.append(ct)
-                if len(working) > 0:
-                    job._working = E.ul(*[E.li(
-                        ar.obj2html(ct.person,ct.person.last_name.upper()),
-                        ' bis %s' % dd.dtos(ct.applies_until)) for ct in working])
-                    showit = True
-                else:
-                    job._working = ''
-        
-                candidates = []
-                qs = job.candidature_set.order_by('date_submitted').filter(state=CandidatureStates.active)
-                qs = pcsw.only_coached_on(qs,today,'person')
-                for cand in qs:
-                    candidates.append(cand)
-                if candidates:
-                    #~ job._candidates = E.ul(*[E.li(unicode(i.person)) for i in candidates])
-                    job._candidates = E.ul(*[E.li(ar.obj2html(i.person,i.person.last_name.upper())) for i in candidates])
-                    showit = True
-                else:
-                    job._candidates = ''
-                        
-                probation = []
-                qs = job.candidature_set.order_by('date_submitted').filter(state=CandidatureStates.probation)
-                qs = pcsw.only_coached_on(qs,today,'person')
-                for cand in qs:
-                    probation.append(cand)
-                if probation:
-                    job._probation = E.ul(*[E.li(ar.obj2html(i.person,i.person.last_name.upper())) for i in probation])
-                    showit = True
-                else:
-                    job._probation = ''
-                    
-                if showit: yield job
-                    
-
 
 
 class JobsOverviewByType(Jobs):
@@ -1407,7 +1311,7 @@ class JobsOverviewByType(Jobs):
     """
     required = dd.required(user_groups=['integ'])
     label = _("Contracts Situation") 
-    column_names = "job_desc:20 working:30 candidates:30 probation:30"
+    column_names = "job_desc:20 working:30 probation:30 candidates:30"
     master_key = 'type'
    
     parameters = dict(
