@@ -58,6 +58,7 @@ pcsw = dd.resolve_app('pcsw')
 contacts = dd.resolve_app('contacts')
 households = dd.resolve_app('households')
 debts = dd.resolve_app('debts')
+courses = dd.resolve_app('courses')
 
 #~ from lino.projects.pcsw.models import Person
 #~ from lino.modlib.cv.models import PersonProperty
@@ -129,7 +130,7 @@ class QuickTest(RemoteAuthTestCase):
             self.assertEqual(
               result['message'],
               """\
-Invalid template '' configured for ContractType u'Art.60\\xa77' (expected filename ending with '.pisa.html').""")
+Invalid template '' configured for ContractType 'Art.60\xa77' (expected filename ending with '.pisa.html').""")
 
         
         #~ def test02(self):
@@ -334,7 +335,7 @@ Belgique""")
         
         expected = "Client(language='%s'," % settings.SITE.DEFAULT_LANGUAGE.django_code
         expected += "last_name='Test'"
-        expected += ",client_state=ClientStates.newcomer:10"
+        expected += ",client_state=<ClientStates.newcomer:10>"
         #~ expected += ",is_active=True"
         #~ expected += r",activity=Activity(name=u'Sozialhilfeempf\xe4nger'))"
         #~ expected += ",activity=1"
@@ -470,10 +471,9 @@ Belgique""")
  Beschreibung                                              Betrag
 --------------------------------------------------------- ---------------
  Monatliche Einkünfte                                      42,00
- Jährliche Einkünfte (48,00 / 12)                          4,00
  Monatliche Ausgaben                                       -986,00
  Monatliche Reserve für jährliche Ausgaben (836,00 / 12)   -69,67
- **Restbetrag für Kredite und Zahlungsrückstände**         **-1 009,67**
+ **Restbetrag für Kredite und Zahlungsrückstände**         **-1 013,67**
 ========================================================= ===============
 """)
         
@@ -496,5 +496,93 @@ Belgique""")
         #~ s2 = b2.BudgetSummary().to_rst()
         self.assertNotEqual(s1,s2)
             
+            
+        cc = courses.CourseContent(name="French")
+        cc.save()
+        courses.CourseRequest(person=self.max_mustermann,
+          date_submitted=settings.SITE.demo_date(),
+          content=cc).save()
         
+        fields = courses.PendingCourseRequests.get_handle().store.list_fields
+        #~ print fields
+        got = [f.name for f in fields]
+        #~ print got
+        expected = """
+        date_submitted workflow_buttons person age address person__gsm 
+        person__phone person__coaches content urgent remark 
+        a16 a25 a31 a41 a51 a61 ax 
+        id disabled_fields disabled_actions disable_editing""".split()
+        self.assertEqual(got,expected)
         
+        """
+        The person__coachings field is a virtual remote field
+        (which caused problems until 20130424).
+        """
+
+        got = '\n'.join([f.as_js(f.name) for f in fields])
+        expected = """\
+{ "type": "date", "name": "date_submitted", "dateFormat": "d.m.Y" }
+{ "name": "workflow_buttons" }
+{ "name": "person" }, 'personHidden'
+{ "type": "int", "name": "age" }
+{ "name": "address" }
+{ "name": "person__gsm" }
+{ "name": "person__phone" }
+{ "name": "person__coaches" }
+{ "name": "content" }, 'contentHidden'
+{ "type": "boolean", "name": "urgent" }
+{ "name": "remark" }
+{ "type": "int", "name": "a16" }
+{ "type": "int", "name": "a25" }
+{ "type": "int", "name": "a31" }
+{ "type": "int", "name": "a41" }
+{ "type": "int", "name": "a51" }
+{ "type": "int", "name": "a61" }
+{ "type": "int", "name": "ax" }
+{ "type": "int", "name": "id" }
+{ "name": "disabled_fields" }
+{ "name": "disabled_actions" }
+{ "name": "disable_editing" }"""
+        #~ print got
+        self.assertEqual(got,expected)
+        
+        response = self.client.get('/api/courses/PendingCourseRequests?fmt=json',REMOTE_USER='root')
+        result = self.check_json_result(response,'count rows success no_data_text title param_values')
+        #~ print result['rows']
+        self.assertEqual(len(result['rows']),2)
+        self.assertEqual(result['rows'][0][8],'')
+        
+        """
+        Traceback reported 20130502
+        """
+        from lino.core import constants
+        accounts = settings.SITE.modules.accounts
+        
+        data = dict()
+        data[constants.URL_PARAM_ACTION_NAME] = 'post'
+        data.update(ref='1013')
+        response = self.client.post('/api/accounts/Accounts',data,REMOTE_USER='root')
+        result = self.check_json_result(response,'message alert success')
+        self.assertEqual(result['success'],False)
+        msg = "This field cannot be null"
+        if not msg in result['message']:
+            self.fail('Expected something containing "%s", got "%s".' % (msg,result['message']))
+            
+        data.update(name="TestAccount")
+        ac = accounts.Chart(name="TestChart")
+        ac.full_clean()
+        ac.save()
+        ag = accounts.Group(name="TestGroup",chart=ac,account_type=accounts.AccountTypes.expenses)
+        ag.full_clean()
+        ag.save()
+        data.update(groupHidden=ag.pk)
+        response = self.client.post('/api/accounts/Accounts',data,REMOTE_USER='root')
+        result = self.check_json_result(response,'message success rows data_record')
+        
+        msg = 'Account "(1013) TestAccount" has been created.'
+        if not msg in result['message']:
+            self.fail('Expected something containing "%s", got "%s".' % (msg,result['message']))
+        
+        self.assertEqual(result['success'],True)
+        obj = accounts.Account.objects.get(group=ag)
+        self.assertEqual(obj.name,"TestAccount")
